const_iv(SUCCESS)
const_iv(DEVICE_NOT_FOUND)
const_iv(DEVICE_NOT_AVAILABLE)
const_iv(COMPILER_NOT_AVAILABLE)
const_iv(MEM_OBJECT_ALLOCATION_FAILURE)
const_iv(OUT_OF_RESOURCES)
const_iv(OUT_OF_HOST_MEMORY)
const_iv(PROFILING_INFO_NOT_AVAILABLE)
const_iv(MEM_COPY_OVERLAP)
const_iv(IMAGE_FORMAT_MISMATCH)
const_iv(IMAGE_FORMAT_NOT_SUPPORTED)
const_iv(BUILD_PROGRAM_FAILURE)
const_iv(MAP_FAILURE)
const_iv(MISALIGNED_SUB_BUFFER_OFFSET)
const_iv(EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)
const_iv(INVALID_VALUE)
const_iv(INVALID_DEVICE_TYPE)
const_iv(INVALID_PLATFORM)
const_iv(INVALID_DEVICE)
const_iv(INVALID_CONTEXT)
const_iv(INVALID_QUEUE_PROPERTIES)
const_iv(INVALID_COMMAND_QUEUE)
const_iv(INVALID_HOST_PTR)
const_iv(INVALID_MEM_OBJECT)
const_iv(INVALID_IMAGE_FORMAT_DESCRIPTOR)
const_iv(INVALID_IMAGE_SIZE)
const_iv(INVALID_SAMPLER)
const_iv(INVALID_BINARY)
const_iv(INVALID_BUILD_OPTIONS)
const_iv(INVALID_PROGRAM)
const_iv(INVALID_PROGRAM_EXECUTABLE)
const_iv(INVALID_KERNEL_NAME)
const_iv(INVALID_KERNEL_DEFINITION)
const_iv(INVALID_KERNEL)
const_iv(INVALID_ARG_INDEX)
const_iv(INVALID_ARG_VALUE)
const_iv(INVALID_ARG_SIZE)
const_iv(INVALID_KERNEL_ARGS)
const_iv(INVALID_WORK_DIMENSION)
const_iv(INVALID_WORK_GROUP_SIZE)
const_iv(INVALID_WORK_ITEM_SIZE)
const_iv(INVALID_GLOBAL_OFFSET)
const_iv(INVALID_EVENT_WAIT_LIST)
const_iv(INVALID_EVENT)
const_iv(INVALID_OPERATION)
const_iv(INVALID_GL_OBJECT)
const_iv(INVALID_BUFFER_SIZE)
const_iv(INVALID_MIP_LEVEL)
const_iv(INVALID_GLOBAL_WORK_SIZE)
const_iv(INVALID_PROPERTY)
